Engines
- [ ] `Jet`
- [x] `CSM`
- [ ] `Nuclear`

Transforms
- [ ] `Viscosity`
- [ ] `Reprocessing`

SEDs
- [x] `Extinction`
- [ ] `MultiBlackbody`
- [ ] `SpectrumBased`
- [ ] `Line`

Optimization
- [ ] Cythonize bottlenecks
- [ ] Load-balance fracking

Input
- [ ] Local modules
- [ ] Non-JSON data (CDS tables, flat files)

Testing
- [ ] Test on Windows (CI not possible yet)

Cleanup
- [x] Make `--quiet` actually quiet

Integration
- [x] Importing `mosfit` for use in other codes

Output
- [x] Model LCs
- [ ] Model SEDs
- [x] Walker distributions
